@@ -1,7 +1,5 @@
 package Form::Factory::Feature::Control::FillOnAssignment;
-our $VERSION = '0.013';
-
-
+our $VERSION = '0.014';
 use Moose;
 
 with qw(
@@ -19,14 +17,11 @@ Form::Factory::Feature::Control::FillOnAssignment - Control gets the value of th
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
   package MyApp::Action::Thing;
-our $VERSION = '0.013';
-
-
   use Form::Factory::Processor;
 
   has_control title => (
@@ -37,9 +32,6 @@ our $VERSION = '0.013';
   );
 
   package Somewhere::Else;
-our $VERSION = '0.013';
-
-
 
   my $interface = Form::Factory->new_interface('HTML');
   my $action = $itnerface->new_action('MyApp::Action::Thing' => {
@@ -102,7 +94,7 @@ This modifies the control such that it will be initialized to the correct value
 sub build_control {
     my ($class, $options, $action, $name, $control) = @_;
 
-    my $attr  = $action->meta->get_attribute($name);
+    my $attr  = $action->meta->find_attribute_by_name($name);
     my $value = $attr->get_value($action);
 
     $control->{options}{value} = $value if defined $value;
